# A Simple Q&A App using Python Django

# Screenshots

Home Page:
<img src="https://github.com/swappsco/django-qa/blob/develop/qa/static/qa/qa_index.jpeg" />

QA Page:
<img src="https://github.com/swappsco/django-qa/blob/develop/qa/static/qa/qa_page.jpeg" />
